# bug-triage -- bug triage and forward tool.
# Copyright (C) 2007  Gustavo R. Montesino
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

import pygtk
pygtk.require("2.0")
import gtk

from bug_store import bug_store

class bug_view:
    """Bug TreeView related callbacks, methods, etc"""

    def __init__(self, xml):
        self.xml = xml

        self.tv = xml.get_widget("tv_bugs")
        self.tv.set_model(bug_store())

        # Bug Number TreeViewColumn
        self.crt_number = gtk.CellRendererText()
        self.tvc_number = gtk.TreeViewColumn("Bug Number", 
            self.crt_number, text=0)
        self.tv.insert_column(self.tvc_number, 0)

        # Package TreeViewColumn
        self.crt_package = gtk.CellRendererText()
        self.tvc_package = gtk.TreeViewColumn("Package",
            self.crt_package, text=1)
        self.tv.insert_column(self.tvc_package, 1)

        # Summary TreeViewColumn
        self.crt_summary = gtk.CellRendererText()
        self.tvc_summary = gtk.TreeViewColumn("Summary",
            self.crt_summary, text=2)
        self.tv.insert_column(self.tvc_summary,2)

        # Severity TreeViewColumn
        self.crt_severity = gtk.CellRendererText()
        self.tvc_severity = gtk.TreeViewColumn("Severity",
            self.crt_severity, text=3)
        self.tv.insert_column(self.tvc_severity, 2)

    def get_model(self):
        """Returns the treeview data model."""
        return self.tv.get_model()

    def set_model(self,model):
        """Set the treeview data model."""
        self.tv.set_model(model)
    
    def get_selection(self):
        """Returns a list with the selected bugs."""
        
        selection = self.tv.get_selection()
        model, rows = selection.get_selected_rows()

        bugs = []
        for row in rows:
            bugs.append(model.get(model.get_iter(row)))

        return bugs

    def on_cursor_changed(self, object, data=None):
        """Activated whenever the cursor is changed"""

        selection = self.tv.get_selection()
        tb_show = self.xml.get_widget("tb_show")
        mi_show = self.xml.get_widget("menuitem_show")

        if selection.count_selected_rows() == 0:
            tb_show.set_sensitive(False)
            mi_show.set_sensitive(False)
        else:
            tb_show.set_sensitive(True)
            mi_show.set_sensitive(True)

# vim: tabstop=4 expandtab shiftwidth=4
